@@ -2236,7 +2236,8 @@ do_shutdown (void *cls)
     curl_download_task = NULL;
   }
   GNUNET_free (target_server_base_url);
-  target_server_base_url = NULL;
+  GNUNET_free (delete_path);
+  GNUNET_free (flip_path_dl);
 }
 
 
@@ -2804,9 +2805,9 @@ handle_flip_path_dl (void *cls,
   char *payload;
 
   tailsize = ntohs (src->header.size) - sizeof (*src);
-
-  if (tailsize != GNUNET_STRINGS_buffer_tokenize
-        ((const char *) &src[1],
+  if (tailsize !=
+      GNUNET_STRINGS_buffer_tokenize (
+        (const char *) &src[1],
         tailsize,
         1,
         &payload))
@@ -2815,7 +2816,7 @@ handle_flip_path_dl (void *cls,
     GNUNET_SERVICE_client_drop (c);
     return;
   }
-
+  GNUNET_free (flip_path_dl);
   flip_path_dl = GNUNET_strdup (payload);
   send_acknowledgement (c);
 }
@@ -2921,7 +2922,7 @@ handle_delete_path (void *cls,
     GNUNET_SERVICE_client_drop (c);
     return;
   }
-
+  GNUNET_free (delete_path);
   delete_path = GNUNET_strdup (payload);
 
   send_acknowledgement (c);
